@@ -8,9 +8,9 @@ from ttkbootstrap.constants import *
 from tkinter.scrolledtext import ScrolledText
 from pathlib import Path
 from . import led, acc, servo, joystick
-import passive_buzzer as pbz
-import PCF8591 as adc
-import ds18b20 as temperature
+from . import passive_buzzer as pbz
+from . import PCF8591 as adc
+from . import ds18b20 as temperature
 # import sys
 # sys.path.insert(0, './vehicle')
 # import vehicle.Adafruit_PWM_Servo_Driver as servo_drv
